#define MROP Mxor
#include "mfbmap.h"
#include "../../../mfb/mfbblt.c"
